import React from 'react';
import PropTypes from 'prop-types';
import loadable from '@loadable/component';
import { getURLParam } from 'gatsby-core-theme/src/helpers/getters';
import Module from '~molecules/module';
import styles from './main.module.scss';
import keygen from '~helpers/keygen';
import settings from '../../../constants/settings.mjs';
import { isSearchPath } from '~helpers/isSearchPath';

const Main = ({
  section = {},
  pageContext = {},
  serverData = {},
  exclOperator = false,
  exclNewsletter = false,
}) => {
  const { page, allMarkets } = pageContext;
  const siteName = process.env.GATSBY_SITE_NAME;
  const showNewsletter =
    !(
      settings.newsletter[siteName]?.filter_pages?.includes('*') ||
      settings.newsletter[siteName]?.filter_pages?.includes(page?.relation_type) ||
      settings.newsletter.default?.filter_pages?.includes(page?.relation_type) ||
      exclNewsletter
    ) && !process.env?.HIDE_NEWSLETTER;
  const pathPrefixes = isSearchPath(allMarkets, page.path);

  const SearchPage = pathPrefixes ? loadable(() => import(`~pages/search`)) : null;
  const HtmlSitemap = pageContext.sitemapData ? loadable(() => import(`~atoms/sitemap`)) : null;
  const AuthorBox = page.author_id ? loadable(() => import(`~atoms/author-box`)) : null;
  const NotFound = page?.path?.includes('404') ? loadable(() => import(`~atoms/not-found`)) : null;
  const Newsletter = showNewsletter ? loadable(() => import('~molecules/newsletter')) : null;
  const NewsletterSuccess =
    showNewsletter && typeof window !== 'undefined' && Boolean(getURLParam('subscribed'))
      ? loadable(() => import(`../newsletter/success`))
      : null;

  return (
    <main className={styles.modulePage || ''}>
      {NotFound && <NotFound pageContext={pageContext} />}
      {HtmlSitemap && <HtmlSitemap pageContext={pageContext} />}
      {section.modules &&
        section.modules.map((module, index) => (
          <Module
            key={keygen()}
            module={module}
            exclOperator={exclOperator}
            page={page}
            pageContext={pageContext}
            serverData={serverData}
            modulePosition={index}
          />
        ))}
      {AuthorBox && (
        <AuthorBox
          author={page.author}
          date={page.updated_at ? page.updated_at : page.created_at}
          readingTime={page.reading_time}
          reviewer={page.reviewer_id && page.reviewer}
        />
      )}
      {SearchPage && <SearchPage page={page} />}
      {Newsletter && <Newsletter page={page} />}
      {NewsletterSuccess && <NewsletterSuccess />}
    </main>
  );
};

Main.propTypes = {
  section: PropTypes.shape({
    modules: PropTypes.arrayOf(
      PropTypes.shape({
        name: PropTypes.string,
      })
    ),
  }),
  page: PropTypes.shape({
    path: PropTypes.string,
  }),
  pageContext: PropTypes.shape({}),
  serverData: PropTypes.shape({}),
  exclOperator: PropTypes.bool,
  exclNewsletter: PropTypes.bool,
};

export default Main;
